**Example 1: 删除产品**



Input: 

```
tccli iotcloud DeleteProduct --cli-unfold-argument  \
    --ProductId ABCDE12345
```

Output: 
```
{
    "Response": {
        "RequestId": "xxxxxxxxxxxxxxxxxxxxxxx"
    }
}
```

